<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>기본 다운로더</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>목록 가져오기</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>URL 입력:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>형식 코드</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>확장자</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>해상도</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>메모</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>엔진 이름:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>클립보드 내용 붙여넣기</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>최근 사용됨</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>다운로드 옵션 설정</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>일괄 다운로더</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>썸네일</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>다운로드할 URL</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>클립보드 URL 붙여넣기</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>URL에 대한 클립보드 모니터링</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>목록에 URL 추가</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>세트</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>재생목록 다운로더</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>다운로드 옵션:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>시간 간격 시작 시간(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>시간 간격 종료 시간(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>장(쉼표로 구분):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>챕터별로 분할</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>숨기기</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>재생목록 URL 입력:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>내부 아카이브 파일 지우기</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>내부 아카이브 파일 사용</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>라이브러리</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>유형</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>위로</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>새로 고치다</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>홈</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>구성</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>일반 옵션</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>트레이 아이콘 표시</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>다운로드 안 된 미디어 목록 자동 저장</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>완료되면 다운로드 자동 숨기기</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>옵션을 기본값으로 재설정</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>기본값 설정</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>사전 설정 옵션</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>다운로드 경로</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>언어 선택</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>엔진의 기본 옵션</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>목록 옵션 가져오기:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>구독</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Ui 이름</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>완료</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>최대 동시 다운로드</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>텍스트 인코딩</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>웹사이트</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>엔진 이름</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>기본</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>추가할 옵션</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>URL 관리자</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>다운로드 옵션</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>어떤 URL을 어떤 엔진으로 관리해야 하는지 설정</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>URL 필터</translation>
    </message>
    <message>
        <source>About</source>
        <translation>프로그램 정보</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>파일 크기</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>라이브러리 탭 활성화</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>버전 정보 표시 및 업데이트 자동 다운로드</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>버전 정보 및 최신 버전 정보 표시</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>버전 정보만 표시</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>아무것도 하지 않음</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>시작 시 작업</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>프록시 설정</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>시스템 프록시 구성 사용</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>수동으로 지정한 프록시 구성 사용</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>수동으로 지정한 프록시 구성
예 1: 192.168.93.89:8080
예 2: ${게이트웨이}:8080</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>환경설정에서 프록시 구성 가져오기</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>프록시 없음</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>%1 사전 설정 옵션</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>확장자가 &quot;.txt&quot;인 파일은 URL만 저장합니다.</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>행 숨기기</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>모든 숨겨진 행 숨기기 해제</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>URL 복사</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>%1 로 URL 열기</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>%1 URL 복사</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>목록을 파일에 저장</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>작성자: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>좋아요 카운트: %1</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>날짜</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>에 대한 답글</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>자막을 파일에 저장</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>엔진 이름:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>파일에서 목록 가져오기</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>사전 설정 옵션</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>비우기</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>다운로드 폴더 열기</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>버전</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>프로젝트 페이지</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>저작권</translation>
    </message>
    <message>
        <source>License</source>
        <translation>특허</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>이메일</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Qt 버전</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>이 프로그램은 무료 소프트웨어입니다. Free Software Foundation에서 발행한 GNU General Public License의 조건에 따라 재배포 및/또는 수정할 수 있습니다. 라이선스 버전 2 또는 (귀하의 선택에 따라) 이후 버전.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>이 프로그램은 유용할 것이라는 희망으로 배포되지만 어떠한 보증도 제공하지 않습니다. 상품성이나 특정 목적에의 적합성에 대한 묵시적인 보증도 제공되지 않습니다. 자세한 내용은 GNU 일반 공중 라이선스를 참조하세요.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>폴란드어(폴란드)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>영어(미국)</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>아랍어</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>한국어(Korean)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>스페인어(스페인)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>중국어(중국)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>터키어(터키)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>러시아어(러시아)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>일본어(일본)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>프랑스어(프랑스)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>이탈리아어(이탈리아)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>스웨덴어(스웨덴)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>독일어(독일)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>포르투갈어(브라질)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>네덜란드어(네덜란드)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>오류, 백엔드 &quot;%1&quot;에 대한 실행 파일을 찾을 수 없습니다.</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>엔진 &quot;%1&quot;에는 최소한 Media Downloader 버전 &quot;%2&quot;이 필요합니다.</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>이러한 검사를 비활성화하려면 다음을 수행하십시오.</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. &quot;구성&quot; 탭으로 이동합니다.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. &quot;일반 옵션&quot; 하위 탭으로 이동합니다.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. 3. &apos;시작 시 작업&apos; 메뉴를 클릭합니다.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. &quot;아무것도 하지 않음&quot;을 선택합니다.</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>휴대용 모드에서 실행</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>설치 모드에서 실행</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>다운로드 경로: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>앱 데이터 경로: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>%1 의 프록시 서버 주소 설정</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>프록시 서버 주소 설정 해제</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>오류, 구성 파일 &quot;%1&quot;을 구문 분석하지 못했습니다.</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>플러그인을 로드하지 못했습니다.</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>실행 파일 &quot;%1&quot;을 찾지 못했습니다.</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>백엔드 &quot;%1&quot;에 대한 python3 실행 파일을 찾지 못했습니다.</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>네트워크 오류가 발생했습니다</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>URL이 지원되지 않습니다</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>다운로드가 취소되었습니다.</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>에러 코드</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>다운로드 실패, 엔진 시작 실패</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>다운로드 실패, 엔진 충돌</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>형식 코드</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>해결</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>메모</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>파일을 쓸 수 없습니다</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>파일을 읽을 수 없습니다</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>경과 시간:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>버전 정보를 찾지 못했습니다. &quot;%1&quot;이(가) 설치되어 있고 제대로 작동하는지 확인하세요</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>발견된 버전</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>쓰기 경로를 열지 못했습니다: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>추출 실패</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>네트워크가 %1 초 이내에 응답하지 못했습니다.</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>다운로드에 실패했습니다. 다음 경로를 생성할 수 없습니다: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>다운로드 시작</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>문제 발생, 폴더를 삭제하지 못함: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>&quot;bsdtar.exe&quot; 실행 파일을 찾지 못했습니다.</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>다운로드 실패</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Github에서 json 파일을 구문 분석하지 못했습니다.</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>다운로드 중</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>타겟</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>업데이트가 완료되었습니다. 새 버전을 사용하려면 다시 시작하세요.</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Windows의 보안 채널</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>다운로드를 완료하였습니다</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>아카이브 추출 중: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>처리</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>다운로드 완료</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>다운로드 폴더를 기본값으로 재설정 중</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>실행 파일 %1 을 시작하지 못했습니다.</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>후처리</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>강제 다운로드</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>로그 창 표시</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>업로드 날짜:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>지속:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>자막 이름</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>다운로드 옵션</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>추가 다운로드 옵션</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>다운로드 시간 간격</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>챕터 다운로드</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>챕터별로 분할</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>미디어가 이미 보관되어 있음</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>어두운</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>방법</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>남은 시간</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>다운로드됨</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>이미 %1 은 다운로드 되었습니다</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>시간이 매우 오래 걸릴 수 있습니다.</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>속도:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>%1 에 대한 업데이트가 있습니다.</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>%1 에 대해 자동 업데이트 사용 안 함</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>최신 버전은 %1입니다. 업데이트 중</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>최신 버전은 %1, 자동 업데이트 사용 안 함</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>최신 버전: %1</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>%1의 버전을 확인하는 중입니다</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>발견된 버전: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>&quot;%1&quot;을(를) 최소한 &quot;%2&quot; 버전으로 업데이트하십시오.</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>요청한 형식을 사용할 수 없습니다</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>잘못된 URL을 입력했습니다.</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>오디오 추출</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>오디오를 MP3로 추출</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>최상의 오디오만 사용 가능</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>최적의 오디오만(MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>최상의 오디오 비디오</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>비디오 해상도가 %1인 최고의 오디오</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>최상의 오디오 전용+썸네일</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>기타 웹사이트</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>유튜브</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>폴더 먼저 표시</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>오름차순으로 정렬</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>날짜별로 정렬</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>이름별로 정렬</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>필터</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>필터 없음</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>내림차순으로 정렬</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>경고: 클립보드 콘텐츠 건너뛰기</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>배치 파일 설정</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>댓글 다운로드 중</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>URL 복사</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>자막 표시</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>댓글 표시</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>미디어 옵션 표시</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>미디어 파트 다운로드</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>날짜 오름차순으로 정렬</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>날짜 내림차순으로 정렬</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>좋아요 기준 정렬</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>자막 다운로드 중</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>기본값으로 설정</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>엔진 파일 선택</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>다운로드 폴더 설정</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">추가</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation type="unfinished">기본값 설정</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>모두 삭제</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>로그</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>지우기</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>컨트롤 숨기기</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>목록 옵션 가져오기:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>URL 복사</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>댓글 표시</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>업데이트된 항목 모두 표시</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>모든 업데이트 다운로드</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>구독 관리</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>다운로드된 페이지 수</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>동영상 정보 다운로드 중</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>컨트롤 표시</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>보이기</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>숨기기</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>시간이 매우 오래 걸릴 수 있습니다.</translation>
    </message>
</context>
</TS>
